<?php

declare(strict_types=1);

namespace Drupal\Tests\kameleoon\Functional;

/**
 * Functional tests for the Anonymous user.
 */
class AnonymousUserTest extends TestBase {

  /**
   * {@inheritdoc}
   */
  protected $profile = 'standard';

  /**
   * Node object.
   *
   * @var Drupal\node\Entity\Node
   */
  protected $node;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    // Create a node.
    $this->node = $this->drupalCreateNode([
      'type' => 'page',
      'uid' => 1,
      'title' => 'Test node',
      'status' => 1,
    ]);
  }

  /**
   * Tests the script added to the page head for anonymous users.
   */
  public function testSyncScript(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    $edit = [
      'sitecode' => 'test_sitecode',
      'script' => 'sync',
      'loading_timeout' => 1500,
      'enable_in_admin' => 0,
      'enable_for_auth' => 0,
    ];
    $this->submitForm($edit, 'Save configuration');

    $this->drupalLogout();

    // Navigate to the node.
    $this->drupalGet($this->node->toUrl());
    $this->assertSession()->statusCodeEquals(200);

    // Assert that the Kameleoon script is added to the page head.
    $this->assertSession()->responseContains('<script src="//test-sitecode.kameleoon.eu/kameleoon.js" type="text/javascript"></script>');
    $this->assertSession()->responseContains('"kameleoon":{"loadingTimeout":1500}');
    $this->assertSession()->responseContains('kameleoon/js/sync.js');
  }

  /**
   * Tests the async-anti-flicker script added to the page head.
   */
  public function testAsyncAntiFlickerScript(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    $edit = [
      'sitecode' => 'test_sitecode',
      'script' => 'async-anti-flicker',
      'loading_timeout' => 2000,
      'enable_in_admin' => 1,
      'enable_for_auth' => 0,
    ];
    $this->submitForm($edit, 'Save configuration');

    $this->drupalLogout();

    // Navigate to the node.
    $this->drupalGet($this->node->toUrl());
    $this->assertSession()->statusCodeEquals(200);

    // Assert that the Kameleoon script is added to the page head.
    $this->assertSession()->responseContains('<script src="//test-sitecode.kameleoon.eu/kameleoon.js" type="text/javascript" fetchpriority="high" async="true"></script>');
    $this->assertSession()->responseContains('"kameleoon":{"loadingTimeout":2000}');
    $this->assertSession()->responseContains('kameleoon/js/async-anti-flicker.js');
  }

  /**
   * Tests the async script added to the page head.
   */
  public function testAsyncScript(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    $edit = [
      'sitecode' => 'test_sitecode',
      'script' => 'async',
      'loading_timeout' => 3000,
      'enable_in_admin' => 0,
      'enable_for_auth' => 1,
    ];
    $this->submitForm($edit, 'Save configuration');

    $this->drupalLogout();

    // Navigate to the node.
    $this->drupalGet($this->node->toUrl());
    $this->assertSession()->statusCodeEquals(200);

    // Assert that the Kameleoon script is added to the page head.
    $this->assertSession()->responseContains('<script src="//test-sitecode.kameleoon.eu/kameleoon.js" type="text/javascript" async="true"></script>');
    $this->assertSession()->responseContains('"kameleoon":{"loadingTimeout":3000}');
    $this->assertSession()->responseContains('kameleoon/js/async.js');
  }

}
