<?php

declare(strict_types=1);

namespace Drupal\Tests\kameleoon\Functional;

/**
 * Functional tests for the authenticated user.
 */
class AuthUserTest extends TestBase {

  /**
   * Tests the script added to the admin page head for authenticated users.
   */
  public function testAsyncScriptForAuthenticatedUsers(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    $edit = [
      'sitecode' => 'test_sitecode',
      'script' => 'async',
      'loading_timeout' => 1000,
      'enable_in_admin' => 1,
      'enable_for_auth' => 1,
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->drupalGet('admin');
    // Assert that the Kameleoon script is added to the page head.
    $this->assertSession()->responseContains('<script src="//test-sitecode.kameleoon.eu/kameleoon.js" type="text/javascript" async="true"></script>');
    $this->assertSession()->responseContains('"kameleoon":{"loadingTimeout":1000}');
    $this->assertSession()->responseContains('kameleoon/js/async.js');
  }

  /**
   * Tests none script added to the admin page for authenticated users.
   */
  public function testNoneAsyncScriptForAuthenticatedUsersAdminPage(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    $edit = [
      'sitecode' => 'test_sitecode',
      'script' => 'async',
      'loading_timeout' => 1000,
      'enable_in_admin' => 0,
      'enable_for_auth' => 1,
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->drupalGet('admin');
    // Assert that the Kameleoon script is not added to the page head.
    $this->assertSession()->responseNotContains('<script src="//test-sitecode.kameleoon.eu/kameleoon.js" type="text/javascript" async="true"></script>');
    $this->assertSession()->responseNotContains('"kameleoon":{"loadingTimeout":1000}');
    $this->assertSession()->responseNotContains('kameleoon/js/async.js');
  }

  /**
   * Tests none script added to the page head for authenticated users.
   */
  public function testNoneAsyncScriptForAuthenticatedUsers(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    $edit = [
      'sitecode' => 'test_sitecode',
      'script' => 'async',
      'loading_timeout' => 1000,
      'enable_in_admin' => 1,
      'enable_for_auth' => 0,
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->drupalGet('admin');
    // Assert that the Kameleoon script is not added to the page head.
    $this->assertSession()->responseNotContains('<script src="//test-sitecode.kameleoon.eu/kameleoon.js" type="text/javascript" async="true"></script>');
    $this->assertSession()->responseNotContains('"kameleoon":{"loadingTimeout":1000}');
    $this->assertSession()->responseNotContains('kameleoon/js/async.js');
  }

}
