<?php

declare(strict_types=1);

namespace Drupal\Tests\kameleoon\Functional;

/**
 * Functional test for the Kameleoon settings form.
 */
class SettingsFormTest extends TestBase {

  /**
   * Tests the settings form.
   */
  public function testSettingsForm(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    // Assert that the form is displayed.
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->fieldExists('sitecode');
    $this->assertSession()->fieldExists('script');
    $this->assertSession()->fieldExists('loading_timeout');
    $this->assertSession()->fieldExists('enable_in_admin');
    $this->assertSession()->fieldExists('enable_for_auth');

    // Submit the form with test values.
    $page = $this->getSession()->getPage();
    $page->selectFieldOption('sitecode', 'test_sitecode');
    $page->selectFieldOption('script', 'async');
    $page->fillField('loading_timeout', '5000');
    $page->checkField('enable_in_admin');
    $page->checkField('enable_for_auth');
    $page->pressButton('Save configuration');

    // Verify that the configuration was saved.
    $config = $this->config('kameleoon.settings');
    $this->assertEquals('test_sitecode', $config->get('sitecode'));
    $this->assertEquals('async', $config->get('script'));
    $this->assertEquals(5000, $config->get('loading_timeout'));
    $this->assertEquals(1, $config->get('enable_in_admin'));
    $this->assertEquals(1, $config->get('enable_for_auth'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('The configuration options have been saved.');
    $this->assertSession()->fieldValueEquals('sitecode', 'test_sitecode');
    $this->assertSession()->fieldValueEquals('script', 'async');
    $this->assertSession()->fieldValueEquals('loading_timeout', '5000');
    $this->assertSession()->checkboxChecked('enable_in_admin');
    $this->assertSession()->checkboxChecked('enable_for_auth');
  }

}
